@@ -33,8 +33,8 @@ class ConstType(object):
     PROJECT_TYPE_API: str = 'API'
     """ [ API项目 ] """
 
-    TASK_TYPE_CODE: str = 'CODE'
-    """ [ 代码任务 ] """
+    TASK_EXECUTION_MODE_CODE: str = 'CODE'
+    """ [ 任务执行模式::代码 ] """
 
-    TASK_TYPE_JSON: str = 'JSON'
-    """ [ JSON任务 ] """
+    TASK_EXECUTION_MODE_JSON: str = 'JSON'
+    """ [ 任务执行模式::JSON ] """
